summaryrefslogtreecommitdiffstats
path: root/karbon/render/art_rgb.c
diff options
context:
space:
mode:
Diffstat (limited to 'karbon/render/art_rgb.c')
-rw-r--r--karbon/render/art_rgb.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/karbon/render/art_rgb.c b/karbon/render/art_rgb.c
index 6dd84bde..4d30fad4 100644
--- a/karbon/render/art_rgb.c
+++ b/karbon/render/art_rgb.c
@@ -30,10 +30,10 @@
/* This is really slow. Is there any way we might speed it up?
Two ideas:
- First, maybe we should be working at 32-bit tqalignment. Then,
+ First, maybe we should be working at 32-bit alignment. Then,
this can be a simple loop over word stores.
- Second, we can keep working at 24-bit tqalignment, but have some
+ Second, we can keep working at 24-bit alignment, but have some
intelligence about storing. For example, we can iterate over
4-pixel chunks (aligned at 4 pixels), with an inner loop
something like:
@@ -100,7 +100,7 @@ art_rgb_fill_run_ (art_u8 *buf, art_u32 rgb, int n)
*buf++ = b;
}
} else {
/* handle prefix up to byte tqalignment */
/* I'm worried about this cast on sizeof(long) != sizeof(uchar *)
architectures, but it _should_ work. */
for (i = 0; ((unsigned long)buf) & 3; i++)
@@ -100,7 +100,7 @@ art_rgb_fill_run_ (art_u8 *buf, art_u32 rgb, int n)
}
} else {
- /* handle prefix up to byte tqalignment */
+ /* handle prefix up to byte alignment */
/* I'm worried about this cast on sizeof(long) != sizeof(uchar *)
architectures, but it _should_ work. */